@@ -50,6 +50,27 @@ map_errors = {
 }
 arg_tz = pytz.timezone('America/Buenos_Aires')
 
+card_brand_map = {
+    # Credito
+    'visa': 1,
+    'diners': 8,
+    'tarshop': 23,
+    'naranja': 24,
+    'pagofacil': 25,
+    'rapipago': 26,
+    'argencard': 30,
+    'cencosud': 43,
+    'cabal': 63,
+    'amex': 65,
+    'master': 104,
+    # Debito
+    'debvisa': 31,
+    'debmaster': 105,
+    'maestro': 106,
+    'debcabal': 108
+}
+
+inverse_card_brand_map = {v: k for k, v in card_brand_map.items()}
 
 def _format_card(response):
     if 'card' in response:
@@ -102,6 +123,11 @@ def _format(response):
         response['status'] = 'refunded'
         response['status_detail'] = 'refunded'
     date = parse_date(response['date']).astimezone(arg_tz)
+    
+    response['payment_method'] = response['payment_method_id']
+    if response['payment_method_id'] in inverse_card_brand_map:
+        response['payment_method'] = inverse_card_brand_map[response['payment_method_id']]
+    
     result = {
         'id': int(response['site_transaction_id']), # Generado por el sdk
         'payment_id': response['id'],               # Genereador por decidir
@@ -113,6 +139,7 @@ def _format(response):
         'payment_day': date,
         'statement_descriptor': response['establishment_name'],
         'payment_method_id': str(response['payment_method_id']),
+        'payment_method': response['payment_method'],
         'installments': response['installments'],
     }
     return result
