@@ -41,7 +41,8 @@ def _format_card(response):
 
 
 def _format(response):
-    if 'payment_method_id' in response and response['payment_method_id'] in card_brand_map:
+    response['payment_method'] = response['payment_method_id']
+    if response['payment_method_id'] in card_brand_map:
         response['payment_method_id'] = str(card_brand_map[response['payment_method_id']])
 
     return {
@@ -54,6 +55,7 @@ def _format(response):
         'payment_day': parse_date(response['date_created']),    # es igual a date_created
         'statement_descriptor': response['statement_descriptor'],
         'payment_method_id': response['payment_method_id'],
+        'payment_method': response['payment_method'],
         'installments': response['installments']
     }
 
@@ -81,7 +83,7 @@ class Payment(MuviBase):
             'external_reference',
             'point_of_interaction',
             'installments',
-            'payment_method_id',
+            # 'payment_method_id',
             'application_fee',
             'notification_url',
             'binary_mode'
@@ -90,8 +92,8 @@ class Payment(MuviBase):
             if f in payment_data:
                 payment_data_mp[f] = payment_data[f]
 
-        if 'payment_method_id' in payment_data_mp and payment_data_mp['payment_method_id'] in inverse_card_brand_map:
-            payment_data_mp['payment_method_id'] = inverse_card_brand_map[payment_data_mp['payment_method_id']]
+        # if 'payment_method_id' in payment_data_mp and payment_data_mp['payment_method_id'] in inverse_card_brand_map:
+        #     payment_data_mp['payment_method_id'] = inverse_card_brand_map[payment_data_mp['payment_method_id']]
 
         if 'payer' in payment_data:
             payment_data_mp["payer"] = {
